@@ -1,11 +1,14 @@
+import numbers
 from typing import Literal, Union, Dict, Sequence, TypedDict, Protocol, TypeVar, List
 
 ID = str
 IDs = List[ID]
 
-Embedding = List[float]
+Number = Union[int, float]
+Embedding = List[Number]
 Embeddings = List[Embedding]
 
+
 Metadata = Dict[str, Union[str, int, float]]
 Metadatas = List[Metadata]
 
@@ -44,6 +47,12 @@ class QueryResult(TypedDict):
     distances: List[List[float]]
 
 
+class IndexMetadata(TypedDict):
+    dimensionality: int
+    elements: int
+    time_created: float
+
+
 class EmbeddingFunction(Protocol):
     def __call__(self, texts: Documents) -> Embeddings:
         ...
@@ -59,7 +68,7 @@ def maybe_cast_one_to_many(
         if isinstance(target, str) and target != None:
             return [target]  # type: ignore
         # One Embedding
-        if isinstance(target[0], float):
+        if isinstance(target[0], (int, float)):
             return [target]  # type: ignore
     # One Metadata dict
     if isinstance(target, dict):
