@@ -92,6 +92,9 @@ if "CHROMA_INTEGRATION_TEST" in os.environ:
     print("Including integration tests")
     test_apis.append(fastapi_integration_api)
 
+if "CHROMA_INTEGRATION_TEST_ONLY" in os.environ:
+    print("Including integration tests only")
+    test_apis = [fastapi_integration_api]
 
 @pytest.mark.parametrize("api_fixture", [local_persist_api])
 def test_persist(api_fixture, request):
@@ -200,11 +203,20 @@ def test_get_nearest_neighbors(api_fixture, request):
     collection.add(**batch_records)
     # assert api.create_index(collection_name="testspace") # default is auto now
 
-    nn = collection.query(query_embeddings=[[1.1, 2.3, 3.2]], n_results=1, where={})
-
+    nn = collection.query(query_embeddings=[1.1, 2.3, 3.2], n_results=1, where={})
     for key in nn.keys():
         assert len(nn[key]) == 1
 
+    nn = collection.query(query_embeddings=[[1.1, 2.3, 3.2]], n_results=1, where={})
+    for key in nn.keys():
+        assert len(nn[key]) == 1
+
+    nn = collection.query(
+        query_embeddings=[[1.1, 2.3, 3.2], [0.1, 2.3, 4.5]], n_results=1, where={}
+    )
+    for key in nn.keys():
+        assert len(nn[key]) == 2
+
 
 @pytest.mark.parametrize("api_fixture", test_apis)
 def test_get_nearest_neighbors_filter(api_fixture, request):
@@ -233,11 +245,8 @@ def test_delete(api_fixture, request):
     collection.add(**batch_records)
     assert collection.count() == 2
 
-    # generic delete on collection not working yet
-    # assert collection.delete() == []
-    # assert collection.count() == 2
-    # assert collection.delete()
-    # assert collection.count() == 0
+    collection.delete()
+    assert collection.count() == 0
 
 
 @pytest.mark.parametrize("api_fixture", test_apis)
@@ -661,6 +670,61 @@ def test_where_valid_operators(api_fixture, request):
         )
 
 
+# TODO: Define the dimensionality of these embeddingds in terms of the default record
+bad_dimensionality_records = {
+    "embeddings": [[1.1, 2.3, 3.2, 4.5], [1.2, 2.24, 3.2, 4.5]],
+    "ids": ["id1", "id2"],
+}
+
+bad_dimensionality_query = {
+    "query_embeddings": [[1.1, 2.3, 3.2, 4.5], [1.2, 2.24, 3.2, 4.5]],
+}
+
+bad_number_of_results_query = {
+    "query_embeddings": [[1.1, 2.3, 3.2], [1.2, 2.24, 3.2]],
+    "n_results": 100,
+}
+
+
+@pytest.mark.parametrize("api_fixture", test_apis)
+def test_dimensionality_validation_add(api_fixture, request):
+    api = request.getfixturevalue(api_fixture.__name__)
+
+    api.reset()
+    collection = api.create_collection("test_dimensionality_validation")
+    collection.add(**minimal_records)
+
+    with pytest.raises(Exception) as e:
+        collection.add(**bad_dimensionality_records)
+    assert "dimensionality" in str(e.value)
+
+
+@pytest.mark.parametrize("api_fixture", test_apis)
+def test_dimensionality_validation_query(api_fixture, request):
+    api = request.getfixturevalue(api_fixture.__name__)
+
+    api.reset()
+    collection = api.create_collection("test_dimensionality_validation_query")
+    collection.add(**minimal_records)
+
+    with pytest.raises(Exception) as e:
+        collection.query(**bad_dimensionality_query)
+    assert "dimensionality" in str(e.value)
+
+
+@pytest.mark.parametrize("api_fixture", test_apis)
+def test_number_of_elements_validation_query(api_fixture, request):
+    api = request.getfixturevalue(api_fixture.__name__)
+
+    api.reset()
+    collection = api.create_collection("test_number_of_elements_validation")
+    collection.add(**minimal_records)
+
+    with pytest.raises(Exception) as e:
+        collection.query(**bad_number_of_results_query)
+    assert "number of elements" in str(e.value)
+
+
 @pytest.mark.parametrize("api_fixture", test_apis)
 def test_query_document_valid_operators(api_fixture, request):
     api = request.getfixturevalue(api_fixture.__name__)
@@ -737,7 +801,7 @@ def test_query_where_document(api_fixture, request):
     collection.add(**contains_records)
 
     items = collection.query(
-        query_embeddings=[0, 0, 0], where_document={"$contains": "doc1"}, n_results=1
+        query_embeddings=[1, 0, 0], where_document={"$contains": "doc1"}, n_results=1
     )
     assert len(items["metadatas"][0]) == 1
 
@@ -746,10 +810,11 @@ def test_query_where_document(api_fixture, request):
     )
     assert len(items["metadatas"][0]) == 2
 
-    with pytest.raises(NoDatapointsException) as e:
+    with pytest.raises(Exception) as e:
         items = collection.query(
             query_embeddings=[0, 0, 0], where_document={"$contains": "bad"}, n_results=1
         )
+        assert "datapoints" in str(e.value)
 
 
 @pytest.mark.parametrize("api_fixture", test_apis)
